translate.lang

Package translate :: Package lang |
[hide private]
[frames] | no frames]

# Package lang

source code

lang contains classes that represent languages and provides language specific information.

All classes inherit from the parent class called common. The type of data includes:

- language codes
- language name
- plurals
- punctuation transformation
- etc

Submodules | [hide private]
Common Language Functionality
translate.lang.common: This module contains all the common features for languages. translate.lang.data: This module stores information and functionality that relates to plurals. translate.lang.factory: This module provides a factory to instantiate language classes. translate.lang.identify: This module contains functions for identifying languages based on language models. translate.lang.poedit: Functions to manage Poedit's language features.
Languages
translate.lang.af: This module represents Afrikaans language. translate.lang.am: This module represents Amharic language. translate.lang.ar: This module represents Arabic language. translate.lang.bn: This module represents Bengali language. translate.lang.code_or: This module represents Oriya language. translate.lang.de: This module represents German language. translate.lang.el: This module represents Greek language. translate.lang.es: This module represents Spanish language. translate.lang.fa: This module represents Persian language. translate.lang.fi: This module represents the Finish language. translate.lang.fr: This module represents French language. translate.lang.he: This module represents Hebrew language. translate.lang.hy: This module represents Armenian language. translate.lang.ja: This module represents Japanese language. translate.lang.km: This module represents Khmer language. translate.lang.kn: This module represents Kannada language. translate.lang.ko: This module represents Korean language. translate.lang.ml: This module represents Malayalam language. translate.lang.ne: This module represents Nepali language. translate.lang.ngram translate.lang.pa: This module represents Punjabi language. translate.lang.st: This module represents the Southern Sotho language. translate.lang.sv: This module represents the Swedish language. translate.lang.te: This module represents Telugu language. translate.lang.ur: This module represents Urdu language. translate.lang.vi: This module represents Vietnamese language. translate.lang.zh: This module represents Chinese language.

Imports: common, data, factory